@@ -1,7 +1,7 @@
 import json
 from sqlalchemy.orm.exc import NoResultFound
 
-from ._util import connect
+from ._util import connect, cprint
 from metacatalog import api
 
 
@@ -13,18 +13,18 @@ def get_uuid(args):
     uuid = args.uuid
     
     if uuid is None:
-        print("You have to specify the UUID")
+        cprint(args, "You have to specify the UUID")
         exit(0)
 
     try:
         entity = api.get_uuid(session, uuid=uuid, not_found='raise')
     except NoResultFound as e:
-        print(str(e))
+        cprint(args, str(e))
         exit(0)
 
     # print
     if args.json:
-        print(json.dumps(entity.to_dict(deep=False), indent=4))
+        cprint(args, json.dumps(entity.to_dict(deep=False), indent=4))
     else:
-        print(entity.full_path)
+        cprint(args, entity.full_path)
 
